@@ -1,23 +1,21 @@
 from urllib.parse import urljoin
 
-from .clients.applied_add_on_client import AppliedAddOnClient
-from .clients.applied_coupon_client import AppliedCouponClient
-from .clients.billable_metric_client import BillableMetricClient
-from .clients.coupon_client import CouponClient
-from .clients.group_client import GroupClient
-from .clients.credit_note_client import CreditNoteClient
-from .clients.plan_client import PlanClient
-from .clients.add_on_client import AddOnClient
-from .clients.organization_client import OrganizationClient
-from .clients.subscription_client import SubscriptionClient
-from .clients.customer_client import CustomerClient
-from .clients.invoice_client import InvoiceClient
-from .clients.event_client import EventClient
-from .clients.fee_client import FeeClient
-from .clients.webhook_client import WebhookClient
-from .clients.wallet_client import WalletClient
-from .clients.wallet_transaction_client import WalletTransactionClient
+from .add_ons.clients import AddOnClient, AppliedAddOnClient
+from .billable_metrics.clients import BillableMetricClient, GroupClient
+from .coupons.clients import AppliedCouponClient, CouponClient
+from .credit_notes.clients import CreditNoteClient
+from .customers.clients import CustomerClient
+from .events.clients import EventClient
+from .fees.clients import FeeClient
 from .functools_ext import callable_cached_property
+from .invoices.clients import InvoiceClient
+from .organizations.clients import OrganizationClient
+from .plans.clients import PlanClient
+from .subscriptions.clients import SubscriptionClient
+from .taxes.clients import TaxClient
+from .wallets.clients import WalletClient, WalletTransactionClient
+from .webhooks.clients import WebhookClient
+from .webhook_endpoints.clients import WebhookEndpointClient
 
 try:
     from typing import Final
@@ -38,20 +36,28 @@ class Client:
         return urljoin(self.api_url if self.api_url else Client.BASE_URL, Client.API_PATH)
 
     @callable_cached_property
-    def events(self) -> EventClient:
-        return EventClient(self.base_api_url, self.api_key)
+    def applied_add_ons(self) -> AppliedAddOnClient:
+        return AppliedAddOnClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
-    def fees(self) -> FeeClient:
-        return FeeClient(self.base_api_url, self.api_key)
+    def add_ons(self) -> AddOnClient:
+        return AddOnClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def billable_metrics(self) -> BillableMetricClient:
+        return BillableMetricClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
     def groups(self) -> GroupClient:
         return GroupClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
-    def subscriptions(self) -> SubscriptionClient:
-        return SubscriptionClient(self.base_api_url, self.api_key)
+    def coupons(self) -> CouponClient:
+        return CouponClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def applied_coupons(self) -> AppliedCouponClient:
+        return AppliedCouponClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
     def credit_notes(self) -> CreditNoteClient:
@@ -61,41 +67,33 @@ class Client:
     def customers(self) -> CustomerClient:
         return CustomerClient(self.base_api_url, self.api_key)
 
+    @callable_cached_property
+    def events(self) -> EventClient:
+        return EventClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def fees(self) -> FeeClient:
+        return FeeClient(self.base_api_url, self.api_key)
+
     @callable_cached_property
     def invoices(self) -> InvoiceClient:
         return InvoiceClient(self.base_api_url, self.api_key)
 
-    @callable_cached_property
-    def applied_coupons(self) -> AppliedCouponClient:
-        return AppliedCouponClient(self.base_api_url, self.api_key)
-
-    @callable_cached_property
-    def applied_add_ons(self) -> AppliedAddOnClient:
-        return AppliedAddOnClient(self.base_api_url, self.api_key)
-
-    @callable_cached_property
-    def billable_metrics(self) -> BillableMetricClient:
-        return BillableMetricClient(self.base_api_url, self.api_key)
-
-    @callable_cached_property
-    def coupons(self) -> CouponClient:
-        return CouponClient(self.base_api_url, self.api_key)
-
-    @callable_cached_property
-    def plans(self) -> PlanClient:
-        return PlanClient(self.base_api_url, self.api_key)
-
-    @callable_cached_property
-    def add_ons(self) -> AddOnClient:
-        return AddOnClient(self.base_api_url, self.api_key)
-
     @callable_cached_property
     def organizations(self) -> OrganizationClient:
         return OrganizationClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
-    def webhooks(self) -> WebhookClient:
-        return WebhookClient(self.base_api_url, self.api_key)
+    def plans(self) -> PlanClient:
+        return PlanClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def subscriptions(self) -> SubscriptionClient:
+        return SubscriptionClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def taxes(self) -> TaxClient:
+        return TaxClient(self.base_api_url, self.api_key)
 
     @callable_cached_property
     def wallets(self) -> WalletClient:
@@ -104,3 +102,11 @@ class Client:
     @callable_cached_property
     def wallet_transactions(self) -> WalletTransactionClient:
         return WalletTransactionClient(self.base_api_url, self.api_key)
+
+    @callable_cached_property
+    def webhooks(self) -> WebhookClient:
+        return WebhookClient(self.base_api_url, self.api_key)
+    
+    @callable_cached_property
+    def webhook_endpoints(self) -> WebhookEndpointClient:
+        return WebhookEndpointClient(self.base_api_url, self.api_key)
